# shazamctl

**shazamctl is not released yet. Install it from Git:**

```sh
pipx install git+https://gitlab.com/notpushkin/shazamctl
```

## Usage

```
$ shazamctl recognize path/to/rickroll.mp3
At 0:00:10: Never Gonna Give You Up by Rick Astley
```

```
$ shazamctl recognize path/to/1h_hardbass_mix.mp3 --multiple
At 0:00:16: Russian Vodka by XS Project
At 0:03:21: ...
```

```
$ shazamctl listen
Not implemented... yet
```
